==> mobiusft-1.3.tar.bz2: mobiusft-1.3/src/python/mobius/system/func_get_devices.cc <==
// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
// Mobius Forensic Toolkit
// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018 Eduardo Aguiar
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any later
// version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
// Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <http://www.gnu.org/licenses/>.
// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=

// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
//! \brief  C++ API module wrapper
//! \author Eduardo Aguiar
// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
#include <Python.h>
#include "device.h"
#include <mobius/system/device_list.h>

// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
//! \brief function mobius.system.get_devices
// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
PyObject*
func_get_devices (PyObject *, PyObject *args)
{
  // parse arguments
  const char *arg_subsystem = nullptr;
  const char *arg_type = nullptr;

  if (!PyArg_ParseTuple (args, "|ss", &arg_subsystem, &arg_type))
    return nullptr;

  // create list
  PyObject *ret = PyList_New (0);
  if (ret == nullptr)
    return nullptr;

  // populate list
  mobius::system::device_list dev_list;

  for (auto dev : dev_list)
    {
      if ((arg_subsystem == nullptr || arg_subsystem == dev.get_subsystem ()) &&
          (arg_type == nullptr || arg_type == dev.get_type ()))
        {
          PyObject *item = PyMobius_System_Device_from_cpp (dev);

          if (item == nullptr)
            {
              Py_CLEAR (ret);
              return nullptr;
            }

          PyList_Append (ret, item);
        }
    }

  return ret;
}

==> mobiusft-1.11.tar.bz2: mobiusft-1.11/src/python/mobius/system/func_get_devices.cc <==
// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
// Mobius Forensic Toolkit
// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019 Eduardo Aguiar
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any later
// version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
// Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <http://www.gnu.org/licenses/>.
// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=

// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
//! \brief  C++ API module wrapper
//! \author Eduardo Aguiar
// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
#include <Python.h>
#include "device.h"
#include <mobius/system/device_list.h>

// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
//! \brief function mobius.system.get_devices
// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
PyObject*
func_get_devices (PyObject *, PyObject *args)
{
  // parse arguments
  const char *arg_subsystem = nullptr;
  const char *arg_type = nullptr;

  if (!PyArg_ParseTuple (args, "|ss", &arg_subsystem, &arg_type))
    return nullptr;

  // create list
  PyObject *ret = PyList_New (0);

  if (ret == nullptr)
    return nullptr;

  // populate list
  mobius::system::device_list dev_list;

  try
    {
      for (const auto& dev : dev_list)
        {
          if ((arg_subsystem == nullptr || arg_subsystem == dev.get_subsystem ()) &&
              (arg_type == nullptr || arg_type == dev.get_type ()))
            {
              PyObject *item = PyMobius_System_Device_from_cpp (dev);

              if (item == nullptr)
                {
                  Py_CLEAR (ret);
                  return nullptr;
                }

              PyList_Append (ret, item);
              Py_DECREF (item);
            }
        }
    }
  catch (const std::exception& e)
    {
      PyErr_SetString (PyExc_Exception, e.what ());
      Py_CLEAR (ret);
      ret = nullptr;
    }  

  return ret;
}
